@@ -46,55 +46,52 @@ DISCONNECTED_INTERVAL = 5 * 60.0
 ON_OFF_BUSY_WAIT_TIME = 66.0
 
 
-class State(Enum):
-    """Controller states:
-
-    Under normal operations:
-        The Controller is READY:
-            - The Controller sends commands directly to the Fireplace
-            - The Controller polls at REFRESH_INTERVAL
-    When toggling the fire power:
-        The Controller remains BUSY for ON_OFF_BUSY_WAIT_TIME:
-            - The Controller buffers requests but does not send to the Fireplace
-    When responses are missed (expected as we are using UDP datagrams):
-        The Controller is NON_RESPONSIVE
-            - The Controller will poll at a (quicker) retry rate
-    When there are no comms for a prolonged period:
-        The Controller enters DISCONNECTED state
-            - The Controller will continue to poll at a reduced rate
-            - The Controller buffers requests but cannot send to the Fireplace
-    """
-
-    BUSY = "BusyWaiting"
-    READY = "Ready"
-    NON_RESPONSIVE = "NonResponsive"
-    DISCONNECTED = "Disconnected"
-
-
-class Fan(Enum):
-    """Supported fan modes"""
-
-    FLAME_EFFECT = "FlameEffect"
-    AUTO = "Auto"
-    FAN_BOOST = "FanBoost"
-
-
-class Settings(Enum):
-    """Available controller system settings - Internal Use Only"""
-
-    IP_ADDRESS = "IPAddress"
-    DEVICE_UID = "DeviceUId"
-    CONTROLLER_STATE = "State"
-    HAS_NEW_TIMERS = "HasNewTimers"
-    FIRE_IS_ON = "FireIsOn"
-    FAN_MODE = "FanMode"
-    DESIRED_TEMP = "DesiredTemp"
-    CURRENT_TEMP = "CurrentTemp"
-
-
 class Controller:
     """Interface to Escea controller"""
 
+    class Fan(Enum):
+        """Supported fan modes"""
+
+        FLAME_EFFECT = "FlameEffect"
+        AUTO = "Auto"
+        FAN_BOOST = "FanBoost"
+
+    class State(Enum):
+        """Controller states:
+
+        Under normal operations:
+            The Controller is READY:
+                - The Controller sends commands directly to the Fireplace
+                - The Controller polls at REFRESH_INTERVAL
+        When toggling the fire power:
+            The Controller remains BUSY for ON_OFF_BUSY_WAIT_TIME:
+                - The Controller buffers requests but does not send to the Fireplace
+        When responses are missed (expected as we are using UDP datagrams):
+            The Controller is NON_RESPONSIVE
+                - The Controller will poll at a (quicker) retry rate
+        When there are no comms for a prolonged period:
+            The Controller enters DISCONNECTED state
+                - The Controller will continue to poll at a reduced rate
+                - The Controller buffers requests but cannot send to the Fireplace
+        """
+
+        BUSY = "BusyWaiting"
+        READY = "Ready"
+        NON_RESPONSIVE = "NonResponsive"
+        DISCONNECTED = "Disconnected"
+
+    class Settings(Enum):
+        """Available controller system settings - Internal Use Only"""
+
+        IP_ADDRESS = "IPAddress"
+        DEVICE_UID = "DeviceUId"
+        CONTROLLER_STATE = "State"
+        HAS_NEW_TIMERS = "HasNewTimers"
+        FIRE_IS_ON = "FireIsOn"
+        FAN_MODE = "FanMode"
+        DESIRED_TEMP = "DesiredTemp"
+        CURRENT_TEMP = "CurrentTemp"
+
     Value = Union[str, int, float, bool, Fan]
     ControllerData = Dict[Settings, Value]
 
@@ -116,8 +113,8 @@ class Controller:
         self._discovery = discovery
         self._system_settings = {}  # type: Controller.ControllerData
         self._prior_settings = {}  # type: Controller.ControllerData
-        self._system_settings[Settings.IP_ADDRESS] = device_ip
-        self._system_settings[Settings.DEVICE_UID] = device_uid
+        self._system_settings[Controller.Settings.IP_ADDRESS] = device_ip
+        self._system_settings[Controller.Settings.DEVICE_UID] = device_uid
 
         self._datagram = Datagram(
             self._discovery.loop, device_ip, self._discovery.sending_lock
@@ -132,7 +129,7 @@ class Controller:
         been contacted and current settings read.
         """
 
-        self._state = State.READY
+        self._state = Controller.State.READY
         self._last_response = 0.0  # Tracks last valid message received
         self._busy_end_time = 0.0  # Tracks when exit BUSY state
         self._last_update = 0.0  # To 'rate limit' the notifications to discovery
@@ -171,18 +168,18 @@ class Controller:
 
             _LOG.debug(
                 "Polling unit %s at address %s (current state is %s)",
-                self._system_settings[Settings.DEVICE_UID],
-                self._system_settings[Settings.IP_ADDRESS],
+                self._system_settings[Controller.Settings.DEVICE_UID],
+                self._system_settings[Controller.Settings.IP_ADDRESS],
                 self._state,
             )
 
-            if self._state == State.READY:
+            if self._state == Controller.State.READY:
                 sleep_time = REFRESH_INTERVAL
-            elif self._state == State.NON_RESPONSIVE:
+            elif self._state == Controller.State.NON_RESPONSIVE:
                 sleep_time = RETRY_INTERVAL
-            elif self._state == State.DISCONNECTED:
+            elif self._state == Controller.State.DISCONNECTED:
                 sleep_time = DISCONNECTED_INTERVAL
-            elif self._state == State.BUSY:
+            elif self._state == Controller.State.BUSY:
                 sleep_time = max(self._busy_end_time - time(), 0.0)
 
             try:
@@ -196,12 +193,12 @@ class Controller:
     @property
     def device_ip(self) -> str:
         """IP Address of the unit"""
-        return self._system_settings[Settings.IP_ADDRESS]
+        return self._system_settings[Controller.Settings.IP_ADDRESS]
 
     @property
     def device_uid(self) -> str:
         """UId of the unit (serial number)"""
-        return self._system_settings[Settings.DEVICE_UID]
+        return self._system_settings[Controller.Settings.DEVICE_UID]
 
     @property
     def discovery(self):
@@ -216,7 +213,7 @@ class Controller:
     @property
     def is_on(self) -> bool:
         """True if the fire is turned on"""
-        return self._get_system_state(Settings.FIRE_IS_ON)
+        return self._get_system_state(Controller.Settings.FIRE_IS_ON)
 
     async def set_on(self, value: bool) -> None:
         """Turn the fire on or off.
@@ -224,23 +221,23 @@ class Controller:
         Note: After systems receives on or off command, must wait ON_OFF_BUSY_TIMEOUT
         before sending further commands (they will be buffered internally)
         """
-        await self._set_system_state(Settings.FIRE_IS_ON, value)
+        await self._set_system_state(Controller.Settings.FIRE_IS_ON, value)
 
     @property
     def fan(self) -> Fan:
         """The current fan level."""
-        return self._get_system_state(Settings.FAN_MODE)
+        return self._get_system_state(Controller.Settings.FAN_MODE)
 
     async def set_fan(self, value: Fan) -> None:
         """The fan level.
         Does not return until command has been sent to the fireplace.
         """
-        await self._set_system_state(Settings.FAN_MODE, value)
+        await self._set_system_state(Controller.Settings.FAN_MODE, value)
 
     @property
     def desired_temp(self) -> float:
         """fireplace DesiredTemp temperature."""
-        return float(self._get_system_state(Settings.DESIRED_TEMP))
+        return float(self._get_system_state(Controller.Settings.DESIRED_TEMP))
 
     async def set_desired_temp(self, value: float):
         """Fireplace DesiredTemp temperature.
@@ -261,12 +258,12 @@ class Controller:
             )
             return
 
-        await self._set_system_state(Settings.DESIRED_TEMP, degrees)
+        await self._set_system_state(Controller.Settings.DESIRED_TEMP, degrees)
 
     @property
     def current_temp(self) -> float:
         """The room air temperature"""
-        return float(self._get_system_state(Settings.CURRENT_TEMP))
+        return float(self._get_system_state(Controller.Settings.CURRENT_TEMP))
 
     @property
     def min_temp(self) -> float:
@@ -305,7 +302,7 @@ class Controller:
                         new state DISCONNECTED
                         notify discovery disconnected
         """
-        if self._state == State.BUSY and time() < self._busy_end_time:
+        if self._state == Controller.State.BUSY and time() < self._busy_end_time:
             return
 
         prior_state = self._state
@@ -313,23 +310,37 @@ class Controller:
         if (response is not None) and (response.response_id == ResponseID.STATUS):
             # We have a valid response - the controller is communicating
 
-            self._state = State.READY
+            self._state = Controller.State.READY
 
             # These values are readonly, so copy them in any case
-            self._system_settings[Settings.HAS_NEW_TIMERS] = response.has_new_timers
-            self._system_settings[Settings.CURRENT_TEMP] = response.current_temp
+            self._system_settings[
+                Controller.Settings.HAS_NEW_TIMERS
+            ] = response.has_new_timers
+            self._system_settings[
+                Controller.Settings.CURRENT_TEMP
+            ] = response.current_temp
 
-            if prior_state == State.READY:
+            if prior_state == Controller.State.READY:
 
                 # Normal operation, update our internal values
-                self._system_settings[Settings.DESIRED_TEMP] = response.desired_temp
+                self._system_settings[
+                    Controller.Settings.DESIRED_TEMP
+                ] = response.desired_temp
                 if response.fan_boost_is_on:
-                    self._system_settings[Settings.FAN_MODE] = Fan.FAN_BOOST
+                    self._system_settings[
+                        Controller.Settings.FAN_MODE
+                    ] = Controller.Fan.FAN_BOOST
                 elif response.flame_effect:
-                    self._system_settings[Settings.FAN_MODE] = Fan.FLAME_EFFECT
+                    self._system_settings[
+                        Controller.Settings.FAN_MODE
+                    ] = Controller.Fan.FLAME_EFFECT
                 else:
-                    self._system_settings[Settings.FAN_MODE] = Fan.AUTO
-                self._system_settings[Settings.FIRE_IS_ON] = response.fire_is_on
+                    self._system_settings[
+                        Controller.Settings.FAN_MODE
+                    ] = Controller.Fan.AUTO
+                self._system_settings[
+                    Controller.Settings.FIRE_IS_ON
+                ] = response.fire_is_on
 
             else:
 
@@ -338,36 +349,39 @@ class Controller:
 
                 if (
                     response.desired_temp
-                    != self._system_settings[Settings.DESIRED_TEMP]
+                    != self._system_settings[Controller.Settings.DESIRED_TEMP]
                 ):
                     await self._set_system_state(
-                        Settings.DESIRED_TEMP,
-                        self._system_settings[Settings.DESIRED_TEMP],
+                        Controller.Settings.DESIRED_TEMP,
+                        self._system_settings[Controller.Settings.DESIRED_TEMP],
                         sync=True,
                     )
 
                 if response.fan_boost_is_on:
-                    response_fan = Fan.FAN_BOOST
+                    response_fan = Controller.Fan.FAN_BOOST
                 elif response.flame_effect:
-                    response_fan = Fan.FLAME_EFFECT
+                    response_fan = Controller.Fan.FLAME_EFFECT
                 else:
-                    response_fan = Fan.AUTO
-                if response_fan != self._system_settings[Settings.FAN_MODE]:
+                    response_fan = Controller.Fan.AUTO
+                if response_fan != self._system_settings[Controller.Settings.FAN_MODE]:
                     await self._set_system_state(
-                        Settings.FAN_MODE,
-                        self._system_settings[Settings.FAN_MODE],
+                        Controller.Settings.FAN_MODE,
+                        self._system_settings[Controller.Settings.FAN_MODE],
                         sync=True,
                     )
 
                 # Do power last, as then we go to BUSY state
-                if response.fire_is_on != self._system_settings[Settings.FIRE_IS_ON]:
+                if (
+                    response.fire_is_on
+                    != self._system_settings[Controller.Settings.FIRE_IS_ON]
+                ):
                     await self._set_system_state(
-                        Settings.FIRE_IS_ON,
-                        self._system_settings[Settings.FIRE_IS_ON],
+                        Controller.Settings.FIRE_IS_ON,
+                        self._system_settings[Controller.Settings.FIRE_IS_ON],
                         sync=True,
                     )
 
-                if prior_state == State.DISCONNECTED:
+                if prior_state == Controller.State.DISCONNECTED:
                     self._discovery.controller_reconnected(self)
 
             if notify:
@@ -389,10 +403,10 @@ class Controller:
         else:
             # No / invalid response, need to check if we need to change state
             if time() - self._last_response < RETRY_TIMEOUT:
-                self._state = State.NON_RESPONSIVE
+                self._state = Controller.State.NON_RESPONSIVE
             else:
-                self._state = State.DISCONNECTED
-                if prior_state != State.DISCONNECTED:
+                self._state = Controller.State.DISCONNECTED
+                if prior_state != Controller.State.DISCONNECTED:
                     self._discovery.controller_disconnected(self, TimeoutError)
 
     async def _request_status(self) -> Message:
@@ -410,17 +424,17 @@ class Controller:
         except ConnectionError:
             pass
         # If we get here... did not receive a response or not valid
-        if self._state != State.DISCONNECTED:
-            self._state = State.NON_RESPONSIVE
+        if self._state != Controller.State.DISCONNECTED:
+            self._state = Controller.State.NON_RESPONSIVE
         return None
 
     def refresh_address(self, address):
         """Called from discovery to point controller to the IP address"""
-        if self._system_settings[Settings.IP_ADDRESS] == address:
+        if self._system_settings[Controller.Settings.IP_ADDRESS] == address:
             return
 
         self._datagram.set_ip(address)
-        self._system_settings[Settings.IP_ADDRESS] = address
+        self._system_settings[Controller.Settings.IP_ADDRESS] = address
 
         # signal the poll loop to wake up and ask for new status
         async def signal_loop(self):
@@ -455,39 +469,39 @@ class Controller:
         # save the new value internally
         self._system_settings[state] = value
 
-        if (not sync) and (self._state != State.READY):
+        if (not sync) and (self._state != Controller.State.READY):
             # We've saved the new value.... just can't send it to the controller yet
             return
 
         command = None
 
-        if state == Settings.FIRE_IS_ON:
+        if state == Controller.Settings.FIRE_IS_ON:
             if value:
                 command = CommandID.POWER_ON
             else:
                 command = CommandID.POWER_OFF
 
-        elif state == Settings.DESIRED_TEMP:
+        elif state == Controller.Settings.DESIRED_TEMP:
             command = CommandID.NEW_SET_TEMP
 
-        elif state == Settings.FAN_MODE:
+        elif state == Controller.Settings.FAN_MODE:
 
             # Fan is implemented via separate FLAME_EFFECT and FAN_BOOST commands
             # Any change to Fan will take one or two separate commands:
             #
             # To AUTO:
             # 1. turn off FAN_BOOST
-            if value == Fan.AUTO:
+            if value == Controller.Fan.AUTO:
                 command = CommandID.FAN_BOOST_OFF
 
             # To FAN_BOOST:
             # 1. Turn off FLAME_EFFECT
-            elif value == Fan.FAN_BOOST:
+            elif value == Controller.Fan.FAN_BOOST:
                 command = CommandID.FLAME_EFFECT_OFF
 
             # To FLAME_EFFECT:
             # 1. Turn off FAN_BOOST
-            elif value == Fan.FLAME_EFFECT:
+            elif value == Controller.Fan.FLAME_EFFECT:
                 command = CommandID.FAN_BOOST_OFF
 
         else:
@@ -515,18 +529,18 @@ class Controller:
             else:
                 return
 
-        if state == Settings.FAN_MODE:
+        if state == Controller.Settings.FAN_MODE:
             # Fan is implemented via separate FLAME_EFFECT and FAN_BOOST commands
             # Any change will take one or two separate commands:
             #
             # To AUTO:
             # 2. turn off FLAME_EFFECT
-            if value == Fan.AUTO:
+            if value == Controller.Fan.AUTO:
                 command = CommandID.FLAME_EFFECT_OFF
 
             # To FAN_BOOST:
             # 2. Turn on FAN_BOOST
-            elif value == Fan.FAN_BOOST:
+            elif value == Controller.Fan.FAN_BOOST:
                 command = CommandID.FAN_BOOST_ON
 
             # To FLAME_EFFECT:
@@ -560,6 +574,6 @@ class Controller:
             await self._refresh_system()
 
         # If get here, and just toggled the fireplace power... need to buffer for a while
-        if state == Settings.FIRE_IS_ON:
-            self._state = State.BUSY
+        if state == Controller.Settings.FIRE_IS_ON:
+            self._state = Controller.State.BUSY
             self._busy_end_time = time() + ON_OFF_BUSY_WAIT_TIME
